@@ -85,11 +85,14 @@ class Agent(Insight, Channel, Catalog, Dataset):
         Insight.__init__(self, self._env, self._token)
         Channel.__init__(self, self._env, self._token, self._agentId, self._domain)
         Catalog.__init__(self, self._env, self._token)
-        Dataset.__init__(self, self._env, self._token)
+        Dataset.__init__(self, self._env, self._token, self._agentId)
 
     def __str__(self):
         return '{}'.format(self._agentId)
 
+    def Dataset(self, dataset_slug):
+        return Dataset(self._env, self._token, self._agentId, dataset_slug)
+
     def switch_agent(self):
 
         data = {
@@ -821,7 +824,7 @@ class Askdata(SignUp):
             self.userid = r_userid.json()['id']
             self.username = r_userid.json()['userName']
 
-    def agent(self, slug="", agent_id="") -> 'Agent':
+    def agent(self, slug="", agent_id='') -> 'Agent':
         # Agent.__init__(self, self, slug=slug)
         return Agent(self, slug=slug, agent_id=agent_id)
 
@@ -1007,7 +1010,6 @@ class Askdata(SignUp):
             })
         return pd.DataFrame(data=columns)
 
-
     def query(self, workspace='', dataset='', fields:list=[], filters=None, sorted_by=None, limit=50):
 
         if (workspace == ''):
@@ -1020,7 +1022,7 @@ class Askdata(SignUp):
         return agent.query(dataset_slug, fields, filters, sorted_by, limit=limit)
 
 
-    def get(self, query, workspace='', dataset='', lang="en", fields:list=[], filters=None, sorted_by=None):
+    def get(self, query, workspace='', dataset='', lang="en", fields:list=[], filters=None, sorted_by=None, get_raw_data=False):
 
 
         s = requests.Session()
@@ -1078,7 +1080,8 @@ class Askdata(SignUp):
             "userId": self.userid,
             "fields": fields,
             "filters": filters,
-            "sorting": sorted_by
+            "sorting": sorted_by,
+            "getRawData": get_raw_data
         }
 
         response = s.post(url=url, json=body, headers=self._headers)
@@ -1109,11 +1112,14 @@ class Askdata(SignUp):
                 for r in filtered_result[1:]:
                     url_i = app_url + "/" + workspace + "/" + r["attachment"]["body"][0]["details"]["datasetSlug"]
                     display(HTML('<p>     {} from the dataset: {} / {} ((<a href="{}" target="_blank">{}</a>)) <- Use this source</p>'.format(self.extract_fields(r["attachment"]["body"][0]["details"]["columns"]), workspace, r["attachment"]["body"][0]["details"]["datasetName"], url_i, url_i)))
-
-            df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"][0]["details"]["rows"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
+            if get_raw_data:
+                df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"][0]["details"]["rawData"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
+            else:
+                df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"][0]["details"]["rows"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
             return df
-        except:
+        except Exception as e:
             logging.error("Query did not produce any result")
+            logging.error(e.__str__())
 
     def load_agents(self):
 
