@@ -1,6 +1,5 @@
 import requests
 import time
-import sqlalchemy
 import yaml
 import os
 import pandas as pd
@@ -16,9 +15,6 @@ from sqlalchemy.orm import sessionmaker, mapper
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.schema import Index
 from threading import Thread
-from sqlalchemy.exc import ArgumentError
-from sqlalchemy.sql import case
-import sqlalchemy
 
 
 import re
@@ -52,13 +48,18 @@ class Dataset():
     _agentId = None
     _domain = None
 
-    def __init__(self, env, token):
+    def __init__(self, env, token, agent_id, slug=''):
 
         self._headers = {
             "Content-Type": "application/json",
             "Authorization": "Bearer" + " " + token
         }
 
+        self._agentId=agent_id
+
+        if(slug!=''):
+            self._get_info_dataset_by_slug(slug)
+
         if env == 'dev':
             self._base_url_dataset = url_list['BASE_URL_DATASET_DEV']
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_DEV']
@@ -146,22 +147,6 @@ class Dataset():
         else:
             raise Exception("dataset didn't instantiate with slug")
 
-    # TODO: Cancellare dopo aver verificato che load_datset_to_df va ok perchè possiamo riutilizzare __get_dataset_settings_info per avere le stesse informazione di return
-
-    # def __get_dataset_connection(self, datasetid):
-    #
-    #     s = requests.Session()
-    #     s.keep_alive = False
-    #     retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-    #     s.mount('https://', HTTPAdapter(max_retries=retries))
-    #
-    #     dataset_url = self._base_url_dataset + '/datasets?agentId=' + self._agentId
-    #     response = requests.get(url=dataset_url, headers=self._headers)
-    #     response.raise_for_status()
-    #     r = response.json()
-    #     connection_df = pd.DataFrame([row['connection'] for row in r if row['id'] == datasetid])
-    #     id_createdby = [row['createdBy'] for row in r if row['id'] == datasetid][0]
-    #     return connection_df.table_id.item(), connection_df.schema.item(), id_createdby
 
     def load_entities_dataset(self, datasetid, select_custom=True):
 
@@ -718,7 +703,7 @@ class Dataset():
 
         self.__put_entity_dataset(entity_code=column_code_settings['code'], dataset_id=self._dataset_id,
                                   settigs_entity=column_code_settings,
-                                  entity_type=column_code_settings['parameterType'],dataset_type=self._dataset_type)
+                                  entity_type=column_code_settings['parameterType'], dataset_type=self._dataset_type)
 
 
     def get_synonym(self,column_code: str) -> list:
